<?php

namespace WPForms\Vendor;

class HTMLPurifier_HTMLModule_NonXMLCommonAttributes extends HTMLPurifier_HTMLModule
{
    /**
     * @type string
     */
    public $name = 'NonXMLCommonAttributes';
    /**
     * @type array
     */
    public $attr_collections = array('Lang' => array('lang' => 'LanguageCode'));
}
// vim: et sw=4 sts=4
